from .util import normalizeBoolean
import re
from builtins import filter

class TargetSplunkVersion(object):
    """
    An object to abstract the target Splunk version that is inspected against, meanwhile providing some useful APIs.
    '"""

    def __init__(self, tags):
        """
        If there are mutiple splunk_x_x tags. Only the last one is considered.
        """
        splunk_tags = list(filter(lambda e: re.match(r'splunk_\d+_\d+', e), tags))
        if len(splunk_tags) < 1:
            self._target_version_value = float('inf')
        else:
            self._target_version_value = self._version_value(splunk_tags[-1])

    def __le__(self, other):
        return self._target_version_value <= self._version_value(other)

    def __eq__(self, other):
        return self._target_version_value == self._version_value(other)

    def __ge__(self, other):
        return self._target_version_value >= self._version_value(other)

    def __lt__(self, other):
        return self._target_version_value < self._version_value(other)

    def __gt__(self, other):
        return self._target_version_value > self._version_value(other)

    def __str__(self):
        return "<{}: {}>".format(self.__class__.__name__, self._target_version_value)

    __repr__ = __str__

    @staticmethod
    def _version_value(tag):
        """
        Convert version number in a splunk_tag into an integer of two digits.
        For example: splunk_7_2 -> 72
        """
        if tag == "py3_migration":
            return 80  # py3_migration is a temporarily used tag
            # valid until Mid June, 2019. Use version value of 80 for it.
        numbers = tag.split('_')[1:]
        numbers = list(map(int, numbers))
        assert len(numbers) <= 2
        value = 0
        for i in range(len(numbers)):
            value += 10 ** (1 - i) * numbers[i]
        return value

